mod md001_test;
mod md002_test;
mod md003_test;
mod md004_test;
mod md005_test;
mod md006_test;
mod md007_test;
mod md009_test;
mod md010_test;
mod md011_test;
mod md012_test;
mod md013_test;
mod md014_test;
mod md018_test;
mod md019_test;
mod md020_test;
mod md021_test;
mod md022_test;
mod md023_extended_test;
mod md023_test;
mod md024_test;
mod md025_test;
mod md026_test;
mod md027_test;
mod md028_test;
mod md029_test;
mod md030_test;
mod md031_test;
mod md032_test;
mod md033_test;
mod md034_ipv6_test;
mod md034_test;
mod md035_test;
mod md036_test;
mod md037_test;
mod md038_nested_backticks_test;
mod md038_test;
mod md039_test;
mod md040_test;
mod md041_test;
mod md042_test;
mod md043_test;
mod md044_test;
mod md045_test;
mod md046_test;
mod md047_test;
mod md048_test;
mod md049_test;
mod md050_test;
mod md051_test;
mod md051_unicode_test;
mod md052_test;
mod md053_additional_test;
mod md053_test;
mod md054_test;
mod md055_test;
mod md056_test;
mod md057_test;
mod md058_test;

// Unicode-specific test modules
mod md001_unicode_test;
mod md005_unicode_test;
mod md006_unicode_test;
mod md029_unicode_test;
mod md054_unicode_test;

// Cross-rule integration test modules
mod emphasis_edge_cases_test;
mod heading_edge_cases_test;
mod inline_content_edge_cases_test;
mod link_edge_cases_test;
mod list_rules_integration_test;

// Test cases for MD003 - Heading Style
#[test]
fn test_md003_fix_consistent_style() {
    // ... existing code ...
}
